@@ -46,7 +46,7 @@ use vars qw/@ISA @EXPORT @EXPORT_OK @EXPORT_TAGS
             $TIMEOUT @MODULES %MODULES %METHODS $AUTOLOAD
             @CURRENCY_RATES_MODULES $USE_EXPERIMENTAL_UA/;
 
-our $VERSION = '1.61_01'; # TRIAL VERSION
+our $VERSION = '1.61_02'; # TRIAL VERSION
 
 @CURRENCY_RATES_MODULES = qw/
     AlphaVantage
@@ -63,6 +63,7 @@ our $VERSION = '1.61_01'; # TRIAL VERSION
     AlphaVantage
     BSEIndia
     Bloomberg
+    BorsaItaliana
     Bourso
     BVB
     CSE
@@ -1678,6 +1679,7 @@ http://www.gnucash.org/
   Finance::Quote::ASEGR,
   Finance::Quote::ASX,
   Finance::Quote::Bloomberg,
+  Finance::Quote::BorsaItaliana,
   Finance::Quote::BSEIndia,
   Finance::Quote::Bourso,
   Finance::Quote::BVB,
